<?php namespace prlbr\aneamal\katex;

/* Copyright 2017, 2019 Martin Janecke <aneamal@prlbr.de>
*
*  This Aneamal math extension is licensed under the MIT License:
*  https://opensource.org/licenses/MIT
*/

/* The function prepares a mathematical expression for client-side parsing by
*  KaTeX. When the function is called for the first time, the function also adds
*  the HTML/CSS/JavaScript code that invokes the KaTeX parser.
*/
return function (array $_) {

	// $_[0]: mathematical expression
	// $_[1]: 'display' for LaTeX displaystyle or 'text' for textstyle
	// $_[2]: URL of the directory in which this file resides
	list ($expression, $style, $path) = $_;

	// katex only needs to be invoked once, which is checked by looking for a
	// static variable $first which is set to false after the first run
	static $first = true;

	if ($first):
		$path_src = htmlspecialchars ($path, ENT_QUOTES | ENT_SUBSTITUTE, 'UTF-8');
		$path_css = str_replace ('"', '\\"', $path);
		$preamble = str_replace (["\n", "\t"], '', '
			<style>@import "' . $path_css . '/katex/katex.min.css"; .katex {font-size:1.1em}</style>
			<script src="' . $path_src . '/katex/katex.min.js"></script>
			<script>
				document.addEventListener ("DOMContentLoaded", function () {
					var d, e, i, m;
					e = document.getElementsByClassName ("_math");
					for (i = 0; i < e.length; i++) {
						d = e[i].tagName.toLowerCase () === "div";
						m = e[i].textContent;
						try {
							katex.render (m, e[i], {displayMode: d, throwOnError: false});
						} catch (error) {
							console.log (error.message);
							e[i].style.color = "#C00";
							e[i].style.whiteSpace = "pre-wrap";
							e[i].textContent = m;
						}
					}
				});
			</script>
		');
		$first = false;
	else:
		$preamble = '';
	endif;

	$tag = $style === 'text'? 'span': 'div';
	$expression = htmlspecialchars (trim ($expression), ENT_SUBSTITUTE, 'UTF-8');
	return "{$preamble}<{$tag} class='_math'>{$expression}</{$tag}>";
};

// Last changed: 2019-L01